@@ -86,7 +86,7 @@ class MatrixClient:
         """
 
         _url, user, domain = parse_account_user(self.account.user)
-        username = "@{}:{}".format(user, domain)
+        username = f"@{user}:{domain}"
         return username
 
     def _get_url(self) -> str:
@@ -195,7 +195,7 @@ class MatrixClient:
 
         # open the config file in write-mode
         path = self._get_path() + CREDENTIALS_FILE_SUFFIX
-        with open(path, "w") as cred_file:
+        with open(path, "w", encoding='UTF-8') as cred_file:
             # write the login details to disk
             json.dump({
                 "homeserver": self._get_url(),  # e.g. "https://matrix.x.org"
@@ -211,7 +211,7 @@ class MatrixClient:
 
         credentials_file = self._get_path() + CREDENTIALS_FILE_SUFFIX
         if os.path.exists(credentials_file):
-            with open(credentials_file, "r") as cred_file:
+            with open(credentials_file, "r", encoding='UTF-8') as cred_file:
                 creds = json.load(cred_file)
                 return (creds["user_id"], creds["device_id"],
                         creds["access_token"])
@@ -437,13 +437,14 @@ class MatrixClient:
         os.chmod(self.account.config.get_dir(), stat.S_IRWXU)
         sync_token_file = self.account.config.get_dir() / f"sync_token{acc_id}"
         if not sync_token_file.exists():
-            open(sync_token_file, "a").close()
+            with open(sync_token_file, "a", encoding='UTF-8'):
+                pass
 
         # make sure only user can read/write file before using it
         os.chmod(sync_token_file, stat.S_IRUSR | stat.S_IWUSR)
 
         try:
-            with open(sync_token_file, "r") as token_file:
+            with open(sync_token_file, "r", encoding='UTF-8') as token_file:
                 token = token_file.readline()
         except OSError:
             token = ""
@@ -468,7 +469,7 @@ class MatrixClient:
         sync_token_file = self.account.config.get_dir() / f"sync_token{acc_id}"
 
         try:
-            with open(sync_token_file, "w") as token_file:
+            with open(sync_token_file, "w", encoding='UTF-8') as token_file:
                 token_file.write(new)
         except OSError:
             return
